pub struct I2c { /* private fields */ }Expand description
LPC-Next0 I2C-bus interfaces
Implementations
Sourceimpl I2c
impl I2c
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn stat(self) -> Reg<Stat, RW>
pub const fn stat(self) -> Reg<Stat, RW>
Status register for Master, Slave, and Monitor functions.
Sourcepub const fn clkdiv(self) -> Reg<Clkdiv, RW>
pub const fn clkdiv(self) -> Reg<Clkdiv, RW>
Clock pre-divider for the entire I2C interface. This determines what time increments are used for the MSTTIME register, and controls some timing of the Slave function.
Sourcepub const fn intstat(self) -> Reg<Intstat, R>
pub const fn intstat(self) -> Reg<Intstat, R>
Interrupt Status register for Master, Slave, and Monitor functions.
Sourcepub const fn mstdat(self) -> Reg<Mstdat, RW>
pub const fn mstdat(self) -> Reg<Mstdat, RW>
Combined Master receiver and transmitter data register.